@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "font-lock-profiler" "0.0.4"
+(define-package "font-lock-profiler" "20250104.2246"
   "Coverage and timing tool for font-lock."
   '((emacs "24.3"))
   :url "https://github.com/Lindydancer/font-lock-profiler"
